.. image:: https://img.shields.io/pypi/v/commonlibs.svg?style=flat
   :target: https://pypi.org/project/commonlibs/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/badge/license-Apache%202-blue.svg
    :target: https://github.com/airinnova/commonlibs/blob/master/LICENSE.txt
    :alt: License

.. image:: https://readthedocs.org/projects/commonlibs/badge/?version=latest
    :target: https://commonlibs.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/airinnova/commonlibs.svg?branch=master
    :target: https://travis-ci.org/airinnova/commonlibs
    :alt: Build status

.. image:: https://codecov.io/gh/airinnova/commonlibs/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/airinnova/commonlibs
    :alt: Coverage

|

.. image:: https://raw.githubusercontent.com/airinnova/commonlibs/master/docs/source/_static/images/logo.png
    :alt: CommonLibs
    :width: 100 px
    :scale: 100 %

*CommonLibs* is a Python library package providing general tools used by other applications. CommonLibs provides the following sub-packages.

* **fileio** Tools for simpler file path handling.
* **logger** Consistent logging across different Python packages.
* **math** Vectors manipulations.
* **dicts** Dictionary tools.
* **model** Tools to build model APIs.

Documentation
-------------

See: https://commonlibs.readthedocs.io/

Installation
------------

.. code::

    pip install commonlibs
